        function getT(rr,cc){
       if(rr==4 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260511 a 00</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==4 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260511 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>3</strong> miembros: 29 <br>3,4,5,6,7,9,14,17,18,20,21,22,23,24,25,29,31,32,33,34,35,37,40,43,44,45,47,49,50';}
       if(rr==4 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260511 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>15</strong> miembros: 22 <strong>control</strong><br>0,1,2,8,10,11,12,13,15,16,19,26,27,28,30,36,38,39,41,42,46,48';}
       if(rr==23 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260511 a 00</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==23 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260511 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>3</strong> miembros: 29 <br>3,4,5,6,7,9,14,17,18,20,21,22,23,24,25,29,31,32,33,34,35,37,40,43,44,45,47,49,50';}
       if(rr==23 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260511 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>15</strong> miembros: 22 <strong>control</strong><br>0,1,2,8,10,11,12,13,15,16,19,26,27,28,30,36,38,39,41,42,46,48';}
       if(rr==25 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260511 a 00</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==25 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260511 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>3</strong> miembros: 29 <br>3,4,5,6,7,9,14,17,18,20,21,22,23,24,25,29,31,32,33,34,35,37,40,43,44,45,47,49,50';}
       if(rr==25 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260511 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>15</strong> miembros: 22 <strong>control</strong><br>0,1,2,8,10,11,12,13,15,16,19,26,27,28,30,36,38,39,41,42,46,48';}
       if(rr==26 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260511 a 00</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==26 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260511 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>3</strong> miembros: 29 <br>3,4,5,6,7,9,14,17,18,20,21,22,23,24,25,29,31,32,33,34,35,37,40,43,44,45,47,49,50';}
       if(rr==26 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260511 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>15</strong> miembros: 22 <strong>control</strong><br>0,1,2,8,10,11,12,13,15,16,19,26,27,28,30,36,38,39,41,42,46,48';}
       if(rr==27 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260511 a 00</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==27 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260511 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>3</strong> miembros: 29 <br>3,4,5,6,7,9,14,17,18,20,21,22,23,24,25,29,31,32,33,34,35,37,40,43,44,45,47,49,50';}
       if(rr==27 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260511 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>15</strong> miembros: 22 <strong>control</strong><br>0,1,2,8,10,11,12,13,15,16,19,26,27,28,30,36,38,39,41,42,46,48';}
       if(rr==28 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260511 a 00</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==28 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260511 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>3</strong> miembros: 29 <br>3,4,5,6,7,9,14,17,18,20,21,22,23,24,25,29,31,32,33,34,35,37,40,43,44,45,47,49,50';}
       if(rr==28 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260511 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>15</strong> miembros: 22 <strong>control</strong><br>0,1,2,8,10,11,12,13,15,16,19,26,27,28,30,36,38,39,41,42,46,48';}
}
